Security Advisories (3)
CVE-2007-4769 (2008-01-09)

The regular expression parser in TCL before 8.4.17, as used in PostgreSQL 8.2 before 8.2.6, 8.1 before 8.1.11, 8.0 before 8.0.15, and 7.4 before 7.4.19, allows remote authenticated users to cause a denial of service (backend crash) via an out-of-bounds backref number.

CVE-2018-25032 (2022-03-25)

zlib before 1.2.12 allows memory corruption when deflating (i.e., when compressing) if the input has many distant matches.

CVE-2011-3045 (2012-03-22)

Integer signedness error in the png_inflate function in pngrutil.c in libpng before 1.4.10beta01, as used in Google Chrome before 17.0.963.83 and other products, allows remote attackers to cause a denial of service (application crash) or possibly execute arbitrary code via a crafted PNG file, a different vulnerability than CVE-2011-3026.

NAME

Tk::IconList - an icon list widget

SYNOPSIS

use Tk::IconList;
$il = $mw->IconList(-browsecmd => sub { ... },
                    -command   => sub { ... })->pack;
$il->Add($icon1, $text1);
$il->Add($icon2, $text2);
$il->Arrange;
...
$il->DeleteAll;

DESCRIPTION

OPTIONS

-browsecmd
-command
-font

-item -foreground|-fg

METHODS

DeleteAll

Deletes all the items inside the canvas subwidget and reset the IconList's state.

Add($image, $text)

Adds an icon into the IconList with the designated image and text.

Arrange

Places the icons in a column-major arrangement.

Get

Return the selected item.

Invoke

Gets called when the user invokes the IconList (usually by double-clicking or pressing the Return key) (internal method).

See($tag)

If the item is not (completely) visible, scroll the canvas so that it becomes visible (internal method).

COPYRIGHT

The original tkfbox.tcl from Tcl/Tk is:

Copyright (c) 1994-1996 Sun Microsystems, Inc.

See the file "license.terms" for information on usage and redistribution of this file, and for a DISCLAIMER OF ALL WARRANTIES.

Translated to Perl/Tk by Slaven Rezic <srezic@cpan.org>.

SEE ALSO

Tk::FBox.