Security Advisories (3)
CVE-2007-4769 (2008-01-09)

The regular expression parser in TCL before 8.4.17, as used in PostgreSQL 8.2 before 8.2.6, 8.1 before 8.1.11, 8.0 before 8.0.15, and 7.4 before 7.4.19, allows remote authenticated users to cause a denial of service (backend crash) via an out-of-bounds backref number.

CVE-2018-25032 (2022-03-25)

zlib before 1.2.12 allows memory corruption when deflating (i.e., when compressing) if the input has many distant matches.

CVE-2011-3045 (2012-03-22)

Integer signedness error in the png_inflate function in pngrutil.c in libpng before 1.4.10beta01, as used in Google Chrome before 17.0.963.83 and other products, allows remote attackers to cause a denial of service (application crash) or possibly execute arbitrary code via a crafted PNG file, a different vulnerability than CVE-2011-3026.

NAME

Tk::Pixmap - Create color images from XPM files.

SYNOPSIS

$widget->Pixmap?(name?,options?)?

DESCRIPTION

XPM is a popular X Window image file format for storing color icons. The Pixmap image type can be used to create color images using XPM files.

Pixmaps support the following options:

-data => string

Specifies the contents of the source pixmap as a string. The string must adhere to the XPM file format (e.g., as generated by the pixmap(1) program). If both the -data and -file options are specified, the -data option takes precedence. Please note that the XPM file parsing code in the xpm library is somewhat fragile. The first line of the string must be "/* XPM */" or otherwise a segmatation fault will be caused.

-file => name

name gives the name of a file whose contents define the source pixmap. The file must adhere to the XPM file format (e.g., as generated by the pixmap(1) program).

IMAGE METHODS

When a pixmap image is created, Tk also creates a new object. This object supports the configure and cget methods described in Tk::options which can be used to enquire and modify the options described above.

SEE ALSO

Tk::Image

KEYWORDS

pixmap, image, tix