Security Advisories (7)
CVE-2007-4769 (2008-01-09)

The regular expression parser in TCL before 8.4.17, as used in PostgreSQL 8.2 before 8.2.6, 8.1 before 8.1.11, 8.0 before 8.0.15, and 7.4 before 7.4.19, allows remote authenticated users to cause a denial of service (backend crash) via an out-of-bounds backref number.

CVE-2018-25032 (2022-03-25)

zlib before 1.2.12 allows memory corruption when deflating (i.e., when compressing) if the input has many distant matches.

CVE-2011-3045 (2012-03-22)

Integer signedness error in the png_inflate function in pngrutil.c in libpng before 1.4.10beta01, as used in Google Chrome before 17.0.963.83 and other products, allows remote attackers to cause a denial of service (application crash) or possibly execute arbitrary code via a crafted PNG file, a different vulnerability than CVE-2011-3026.

CVE-2016-10087 (2017-01-30)

The png_set_text_2 function in libpng 0.71 before 1.0.67, 1.2.x before 1.2.57, 1.4.x before 1.4.20, 1.5.x before 1.5.28, and 1.6.x before 1.6.27 allows context-dependent attackers to cause a NULL pointer dereference vectors involving loading a text chunk into a png structure, removing the text, and then adding another text chunk to the structure.

CVE-2007-4772 (2008-01-09)

The regular expression parser in TCL before 8.4.17, as used in PostgreSQL 8.2 before 8.2.6, 8.1 before 8.1.11, 8.0 before 8.0.15, and 7.4 before 7.4.19, allows context-dependent attackers to cause a denial of service (infinite loop) via a crafted regular expression.

CVE-2007-6067 (2008-01-09)

Algorithmic complexity vulnerability in the regular expression parser in TCL before 8.4.17, as used in PostgreSQL 8.2 before 8.2.6, 8.1 before 8.1.11, 8.0 before 8.0.15, and 7.4 before 7.4.19, allows remote authenticated users to cause a denial of service (memory consumption) via a crafted "complex" regular expression with doubly-nested states.

CVE-2017-12652 (2019-07-10)

libpng before 1.6.32 does not properly check the length of chunks against the user limit.

NAME

Tk::Font - a class for finding X Fonts

SYNOPSIS

use Tk::X11Font;

$font = $widget->X11Font(foundry => 'adobe',
                      family  => 'times',
                      point   => 120
                     );

$font = $widget->X11Font('*-courier-medium-r-normal-*-*');

DESCRIPTION

This module can be use to interrogate the X server what fonts are
avaliable.

METHODS

Foundry( [ $val ] )

Family( [ $val ] )

Weight( [ $val ] )

Slant( [ $val ] )

Swidth( [ $val ] )

Adstyle( [ $val ] )

Pixel( [ $val ] )

Point( [ $val ] )

Xres( [ $val ] )

Yres( [ $val ] )

Space( [ $val ] )

Avgwidth( [ $val ] )

Registry( [ $val ] )

Encoding( [ $val ] )

Set the given field in the font name to $val if given and return the current or previous value

Name( [ $max ] )

In a list context it returns a list of all font names that match the fields given. It will return a maximum of $max names, or 128 if $max is not given.

In a scalar contex it returns the first matching name or undef

Clone( [ key => value, [ ...]] )

Create a duplicate of the curent font object and modify the given fields

AUTHOR

Graham Barr <Graham.Barr@tiuk.ti.com>

HISTORY

11-Jan-96 Initial version

08-Nov-98 Renamed for Tk800.012

COPYRIGHT

Copyright (c) 1995-1996 Graham Barr. All rights reserved. This program is free software; you can redistribute it and/or modify it under the same terms as Perl itself.