Security Advisories (3)
CVE-2007-4769 (2008-01-09)

The regular expression parser in TCL before 8.4.17, as used in PostgreSQL 8.2 before 8.2.6, 8.1 before 8.1.11, 8.0 before 8.0.15, and 7.4 before 7.4.19, allows remote authenticated users to cause a denial of service (backend crash) via an out-of-bounds backref number.

CVE-2018-25032 (2022-03-25)

zlib before 1.2.12 allows memory corruption when deflating (i.e., when compressing) if the input has many distant matches.

CVE-2011-3045 (2012-03-22)

Integer signedness error in the png_inflate function in pngrutil.c in libpng before 1.4.10beta01, as used in Google Chrome before 17.0.963.83 and other products, allows remote attackers to cause a denial of service (application crash) or possibly execute arbitrary code via a crafted PNG file, a different vulnerability than CVE-2011-3026.

NAME

Tk::chooseColor - pops up a dialog box for the user to select a color.

SYNOPSIS

$color = $widget->chooseColor?(-option=>value, ...)?;

DESCRIPTION

The method chooseColor is implemented as a perl wrapper on the core tk "command" tk_chooseColor, and $widget is passed as the argument to the hidden -parent option. The implementation of internal tk_chooseColor is platform specific, on Win32 it is a native dialog, and on UNIX/X11 it is implemented in terms of Tk::ColorEditor.

The chooseColor method pops up a dialog box for the user to select a color. The following option-value pairs are possible as command line arguments:

-initialcolor=>color

Specifies the color to display in the color dialog when it pops up. color must be in a form acceptable to the Tk_GetColor function.

-parent=>$widget

Makes $widget the logical parent of the color dialog. The color dialog is displayed on top of its parent window.

-title=>titleString

Specifies a string to display as the title of the dialog box. If this option is not specified, then a default title will be displayed.

If the user selects a color, tk_chooseColor will return the name of the color in a form acceptable to Tk_GetColor. If the user cancels the operation, the command will return undef.

EXAMPLE

$widget->configure(-fg => $parent->chooseColor(-initialcolor => 'gray',
                                               -title => "Choose color"));

KEYWORDS

color selection dialog